@@ -25,6 +25,7 @@ import (
 	_ "knative.dev/serving/test/defaultsystem"
 
 	pkgTest "knative.dev/pkg/test"
+	"knative.dev/pkg/test/logging"
 	"knative.dev/pkg/test/logstream"
 
 	// Mysteriously required to support GCP auth (required by k8s libs). Apparently just importing it is enough. @_@ side effects @_@. https://github.com/kubernetes/client-go/issues/242
@@ -35,6 +36,7 @@ import (
 const (
 	// Test image names
 	Autoscale           = "autoscale"
+	EmptyDir            = "emptydir"
 	Failing             = "failing"
 	HelloVolume         = "hellovolume"
 	HelloWorld          = "helloworld"
@@ -43,6 +45,7 @@ const (
 	PizzaPlanet1        = "pizzaplanetv1"
 	PizzaPlanet2        = "pizzaplanetv2"
 	Protocols           = "protocols"
+	Readiness           = "readiness"
 	Runtime             = "runtime"
 	SingleThreadedImage = "singlethreaded"
 	Timeout             = "timeout"
@@ -55,6 +58,7 @@ const (
 	PizzaPlanetText2 = "Re-energize yourself with a slice of pepperoni!"
 	HelloWorldText   = "Hello World! How about some tasty noodles?"
 	HelloHTTP2Text   = "Hello, New World! How about donuts and coffee?"
+	EmptyDirText     = "From file in empty dir!"
 
 	MultiContainerResponse = "Yay!! multi-container works"
 
@@ -69,17 +73,28 @@ const (
 )
 
 // Setup creates client to run Knative Service requests
-func Setup(t testing.TB) *Clients {
+func Setup(t testing.TB, namespace ...string) *Clients {
 	t.Helper()
+	logging.InitializeLogger()
 
 	if !ServingFlags.DisableLogStream {
 		cancel := logstream.Start(t)
 		t.Cleanup(cancel)
 	}
 
-	clients, err := NewClients(pkgTest.Flags.Kubeconfig, pkgTest.Flags.Cluster, ServingFlags.TestNamespace)
+	cfg, err := pkgTest.Flags.GetRESTConfig()
 	if err != nil {
-		t.Fatal("Couldn't initialize clients", "error", err.Error())
+		t.Fatal("Couldn't get REST config", "error", err)
+	}
+
+	ns := ServingFlags.TestNamespace
+	if len(namespace) > 0 {
+		ns = namespace[0]
+	}
+
+	clients, err := NewClients(cfg, ns)
+	if err != nil {
+		t.Fatal("Couldn't initialize clients", "error", err)
 	}
 	return clients
 }
