@@ -15,9 +15,11 @@ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */
+
 package e2e
 
 import (
+	"context"
 	"fmt"
 	"strings"
 	"testing"
@@ -26,10 +28,9 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
 
+	netpkg "knative.dev/networking/pkg"
 	"knative.dev/pkg/apis/duck"
-	"knative.dev/pkg/network"
 	"knative.dev/pkg/ptr"
-	"knative.dev/pkg/test/logstream"
 	"knative.dev/serving/pkg/apis/serving"
 	v1 "knative.dev/serving/pkg/apis/serving/v1"
 	"knative.dev/serving/pkg/reconciler/route/resources/labels"
@@ -46,30 +47,25 @@ import (
 // to helloworld app when trying to communicate via local address only.
 func TestSubrouteLocalSTS(t *testing.T) { // We can't use a longer more descriptive name because routes will fail DNS checks. (Max 64 characters)
 	t.Parallel()
-	cancel := logstream.Start(t)
-	defer cancel()
 
 	clients := Setup(t)
 
 	t.Log("Creating a Service for the helloworld test app.")
 	names := test.ResourceNames{
 		Service: test.ObjectNameForTest(t),
-		Image:   "helloworld",
+		Image:   test.HelloWorld,
 	}
 
-	test.CleanupOnInterrupt(func() { test.TearDown(clients, names) })
-	defer test.TearDown(clients, names)
+	test.EnsureTearDown(t, clients, &names)
 
-	tag := "current"
+	const tag = "current"
 
-	withInternalVisibility := rtesting.WithServiceLabel(serving.VisibilityLabelKey, serving.VisibilityClusterLocal)
+	withInternalVisibility := rtesting.WithServiceLabel(netpkg.VisibilityLabelKey, serving.VisibilityClusterLocal)
 	withTrafficSpec := rtesting.WithRouteSpec(v1.RouteSpec{
-		Traffic: []v1.TrafficTarget{
-			{
-				Tag:     tag,
-				Percent: ptr.Int64(100),
-			},
-		},
+		Traffic: []v1.TrafficTarget{{
+			Tag:     tag,
+			Percent: ptr.Int64(100),
+		}},
 	})
 
 	resources, err := v1test.CreateServiceReady(t, clients, &names, withInternalVisibility, withTrafficSpec)
@@ -77,7 +73,7 @@ func TestSubrouteLocalSTS(t *testing.T) { // We can't use a longer more descript
 		t.Fatalf("Failed to create initial Service: %v: %v", names.Service, err)
 	}
 
-	t.Logf("helloworld internal domain is %s.", resources.Route.Status.URL.Host)
+	t.Log("helloworld internal domain is ", resources.Route.Status.URL.Host)
 
 	// helloworld app and its route are ready. Running the test cases now.
 	for _, tc := range testCases {
@@ -85,6 +81,7 @@ func TestSubrouteLocalSTS(t *testing.T) { // We can't use a longer more descript
 		helloworldURL := resources.Route.Status.Address.URL.URL()
 		helloworldURL.Host = strings.TrimSuffix(domain, tc.suffix)
 		t.Run(tc.name, func(t *testing.T) {
+			t.Parallel()
 			testProxyToHelloworld(t, clients, helloworldURL, true, false)
 		})
 	}
@@ -92,8 +89,6 @@ func TestSubrouteLocalSTS(t *testing.T) { // We can't use a longer more descript
 
 func TestSubrouteVisibilityPublicToPrivate(t *testing.T) {
 	t.Parallel()
-	cancel := logstream.Start(t)
-	defer cancel()
 
 	clients := Setup(t)
 
@@ -103,11 +98,12 @@ func TestSubrouteVisibilityPublicToPrivate(t *testing.T) {
 		Image:   "helloworld",
 	}
 
-	test.CleanupOnInterrupt(func() { test.TearDown(clients, names) })
-	defer test.TearDown(clients, names)
+	test.EnsureTearDown(t, clients, &names)
 
-	subrouteTag1 := "my-tag"
-	subrouteTag2 := "my-tag2"
+	const (
+		subrouteTag1 = "my-tag"
+		subrouteTag2 = "my-tag2"
+	)
 
 	withTrafficSpec := rtesting.WithRouteSpec(v1.RouteSpec{
 		Traffic: []v1.TrafficTarget{{
@@ -127,14 +123,14 @@ func TestSubrouteVisibilityPublicToPrivate(t *testing.T) {
 	}
 
 	if isRouteClusterLocal(resources.Route.Status) {
-		t.Fatalf("Expected route to be not cluster local")
+		t.Fatal("Expected route to be not cluster local")
 	}
 
 	// Update subroute1 to private.
 	serviceName := serviceNameForRoute(subrouteTag1, resources.Route.Name)
-	svc, err := clients.KubeClient.Kube.CoreV1().Services(test.ServingNamespace).Get(serviceName, metav1.GetOptions{})
+	svc, err := clients.KubeClient.CoreV1().Services(test.ServingFlags.TestNamespace).Get(context.Background(), serviceName, metav1.GetOptions{})
 	if err != nil {
-		t.Fatalf("Failed to get k8s service to modify: %v", err)
+		t.Fatal("Failed to get k8s service to modify:", err)
 	}
 
 	svcCopy := svc.DeepCopy()
@@ -142,11 +138,11 @@ func TestSubrouteVisibilityPublicToPrivate(t *testing.T) {
 
 	svcpatchBytes, err := duck.CreateBytePatch(svc, svcCopy)
 	if err != nil {
-		t.Fatalf(err.Error())
+		t.Fatal(err.Error())
 	}
 
-	if _, err = clients.KubeClient.Kube.CoreV1().Services(test.ServingNamespace).Patch(serviceName, types.JSONPatchType, svcpatchBytes); err != nil {
-		t.Fatalf("Failed to patch service: %v", err)
+	if _, err = clients.KubeClient.CoreV1().Services(test.ServingFlags.TestNamespace).Patch(context.Background(), serviceName, types.JSONPatchType, svcpatchBytes, metav1.PatchOptions{}); err != nil {
+		t.Fatal("Failed to patch service:", err)
 	}
 
 	//Create subroute2 in kservice.
@@ -158,17 +154,17 @@ func TestSubrouteVisibilityPublicToPrivate(t *testing.T) {
 		})
 
 	if _, err = v1test.UpdateServiceRouteSpec(t, clients, names, v1.RouteSpec{Traffic: ksvcCopyRouteTraffic}); err != nil {
-		t.Fatalf("Failed to patch service: %v", err)
+		t.Fatal("Failed to patch service:", err)
 	}
 
 	if err = v1test.WaitForRouteState(clients.ServingClient, resources.Route.Name, func(r *v1.Route) (bool, error) {
-		//Check subroute1 is not cluster-local
+		// Check subroute1 is not cluster-local
 		if isClusterLocal, err := isTrafficClusterLocal(r.Status.Traffic, subrouteTag1); err != nil {
 			return false, err
 		} else if !isClusterLocal {
 			return false, nil
 		}
-		//Check subroute2 is cluster local
+		// Check subroute2 is cluster local
 		if isClusterLocal, err := isTrafficClusterLocal(r.Status.Traffic, subrouteTag2); err != nil {
 			return false, nil
 		} else if isClusterLocal {
@@ -179,20 +175,20 @@ func TestSubrouteVisibilityPublicToPrivate(t *testing.T) {
 		t.Fatalf("Expected subroute1 with tag %s to be not cluster local; subroute2 with tag %s to be cluster local: %v", subrouteTag1, subrouteTag2, err)
 	}
 
-	//Update route to private.
-	if _, err = v1test.PatchService(t, clients, resources.Service, func(s *v1.Service) {
+	// Update route to private.
+	if _, err := v1test.PatchService(t, clients, resources.Service, func(s *v1.Service) {
 		labels.SetVisibility(&s.ObjectMeta, true)
 	}); err != nil {
-		t.Fatalf("Failed to patch service: %s", err.Error())
+		t.Fatal("Failed to patch service:", err.Error())
 	}
 
-	if err = v1test.WaitForRouteState(clients.ServingClient, resources.Route.Name, func(r *v1.Route) (bool, error) {
+	if err := v1test.WaitForRouteState(clients.ServingClient, resources.Route.Name, func(r *v1.Route) (bool, error) {
 		return isRouteClusterLocal(r.Status), nil
 	}, "Route is cluster local"); err != nil {
-		t.Fatalf("Route did not become cluster local: %s", err.Error())
+		t.Fatal("Route did not become cluster local:", err.Error())
 	}
 
-	clusterLocalRoute, err := clients.ServingClient.Routes.Get(resources.Route.Name, metav1.GetOptions{})
+	clusterLocalRoute, err := clients.ServingClient.Routes.Get(context.Background(), resources.Route.Name, metav1.GetOptions{})
 	if err != nil {
 		t.Fatalf(err.Error())
 	}
@@ -208,8 +204,6 @@ func TestSubrouteVisibilityPublicToPrivate(t *testing.T) {
 
 func TestSubrouteVisibilityPrivateToPublic(t *testing.T) {
 	t.Parallel()
-	cancel := logstream.Start(t)
-	defer cancel()
 
 	clients := Setup(t)
 
@@ -219,24 +213,21 @@ func TestSubrouteVisibilityPrivateToPublic(t *testing.T) {
 		Image:   "helloworld",
 	}
 
-	test.CleanupOnInterrupt(func() { test.TearDown(clients, names) })
-	defer test.TearDown(clients, names)
+	test.EnsureTearDown(t, clients, &names)
+	const (
+		subrouteTag1 = "my-tag"
+		subrouteTag2 = "my-tag2"
+	)
 
-	subrouteTag1 := "my-tag"
-	subrouteTag2 := "my-tag2"
-
-	withInternalVisibility := rtesting.WithServiceLabel(serving.VisibilityLabelKey, serving.VisibilityClusterLocal)
+	withInternalVisibility := rtesting.WithServiceLabel(netpkg.VisibilityLabelKey, serving.VisibilityClusterLocal)
 	withTrafficSpec := rtesting.WithRouteSpec(v1.RouteSpec{
-		Traffic: []v1.TrafficTarget{
-			{
-				Tag:     subrouteTag1,
-				Percent: ptr.Int64(50),
-			},
-			{
-				Tag:     subrouteTag2,
-				Percent: ptr.Int64(50),
-			},
-		},
+		Traffic: []v1.TrafficTarget{{
+			Tag:     subrouteTag1,
+			Percent: ptr.Int64(50),
+		}, {
+			Tag:     subrouteTag2,
+			Percent: ptr.Int64(50),
+		}},
 	})
 	resources, err := v1test.CreateServiceReady(t, clients, &names, withTrafficSpec, withInternalVisibility)
 	if err != nil {
@@ -245,7 +236,7 @@ func TestSubrouteVisibilityPrivateToPublic(t *testing.T) {
 
 	for _, tag := range []string{subrouteTag1, subrouteTag2} {
 		if isClusterLocal, err := isTrafficClusterLocal(resources.Route.Status.Traffic, tag); err != nil {
-			t.Fatalf(err.Error())
+			t.Fatal(err.Error())
 		} else if !isClusterLocal {
 			t.Fatalf("Expected subroute with tag %s to be cluster local", tag)
 		}
@@ -255,11 +246,11 @@ func TestSubrouteVisibilityPrivateToPublic(t *testing.T) {
 		t.Fatalf("Expected route to be cluster local")
 	}
 
-	//Update subroute1 to private
+	// Update subroute1 to private
 	serviceName := serviceNameForRoute(subrouteTag1, resources.Route.Name)
-	svc, err := clients.KubeClient.Kube.CoreV1().Services(test.ServingNamespace).Get(serviceName, metav1.GetOptions{})
+	svc, err := clients.KubeClient.CoreV1().Services(test.ServingFlags.TestNamespace).Get(context.Background(), serviceName, metav1.GetOptions{})
 	if err != nil {
-		t.Fatalf("Failed to get k8s service to modify: %s", err.Error())
+		t.Fatal("Failed to get k8s service to modify:", err.Error())
 	}
 
 	svcCopy := svc.DeepCopy()
@@ -270,13 +261,13 @@ func TestSubrouteVisibilityPrivateToPublic(t *testing.T) {
 		t.Fatalf(err.Error())
 	}
 
-	if _, err = clients.KubeClient.Kube.CoreV1().Services(test.ServingNamespace).Patch(serviceName, types.JSONPatchType, svcpatchBytes); err != nil {
-		t.Fatalf("Failed to patch service: %s", err.Error())
+	if _, err = clients.KubeClient.CoreV1().Services(test.ServingFlags.TestNamespace).Patch(context.Background(), serviceName, types.JSONPatchType, svcpatchBytes, metav1.PatchOptions{}); err != nil {
+		t.Fatal("Failed to patch service:", err.Error())
 	}
 
 	afterCh := time.After(5 * time.Second)
 
-	// check subroutes are private
+	// Check that the subroutes are private.
 	if err = v1test.WaitForRouteState(clients.ServingClient, resources.Route.Name, func(r *v1.Route) (bool, error) {
 		for _, tag := range []string{subrouteTag1, subrouteTag2} {
 			if isClusterLocal, err := isTrafficClusterLocal(r.Status.Traffic, tag); err != nil {
@@ -286,14 +277,14 @@ func TestSubrouteVisibilityPrivateToPublic(t *testing.T) {
 			}
 		}
 		select {
-		// consistently check for subroutes to be cluster-local for 5s
+		// Consistently check for subroutes to be cluster-local for 5s
 		case <-afterCh:
 			return true, nil
 		default:
 			return false, nil
 		}
 	}, "sub routes are not ready"); err != nil {
-		t.Fatalf("Expected sub routes are not cluster local: %s", err.Error())
+		t.Fatal("Expected sub routes are not cluster local:", err.Error())
 	}
 
 	// check route is private
@@ -306,39 +297,39 @@ func TestSubrouteVisibilityPrivateToPublic(t *testing.T) {
 	if _, err = v1test.PatchService(t, clients, resources.Service, func(s *v1.Service) {
 		labels.SetVisibility(&s.ObjectMeta, false)
 	}); err != nil {
-		t.Fatalf("Failed to patch service: %s", err.Error())
+		t.Fatal("Failed to patch service:", err.Error())
 	}
 
 	if err = v1test.WaitForRouteState(clients.ServingClient, resources.Route.Name, func(r *v1.Route) (b bool, e error) {
 		return !isRouteClusterLocal(r.Status), nil
 	}, "Route is public"); err != nil {
-		t.Fatalf("Route is not public: %s", err.Error())
+		t.Fatal("Route is not public:", err.Error())
 	}
 
-	publicRoute, err := clients.ServingClient.Routes.Get(resources.Route.Name, metav1.GetOptions{})
+	publicRoute, err := clients.ServingClient.Routes.Get(context.Background(), resources.Route.Name, metav1.GetOptions{})
 	if err != nil {
 		t.Fatalf(err.Error())
 	}
 
-	//Check subroute 2 is public.
+	// Check subroute 2 is public.
 	if isClusterLocal, err := isTrafficClusterLocal(publicRoute.Status.Traffic, subrouteTag2); err != nil {
 		t.Fatalf(err.Error())
 	} else if isClusterLocal {
 		t.Fatalf("Expected subroute with tag %s to be not cluster local", subrouteTag2)
 	}
 
-	//Check subroute1 is  private. This check is expected to fail on v0.8.1 and earlier as subroute1 becomes public)
+	// Check subroute1 is  private. This check is expected to fail on v0.8.1 and earlier as subroute1 becomes public)
 	if isClusterLocal, err := isTrafficClusterLocal(publicRoute.Status.Traffic, subrouteTag1); err != nil {
 		t.Fatalf(err.Error())
 	} else if !isClusterLocal {
 		t.Fatalf("Expected subroute with tag %s to be cluster local", subrouteTag1)
 	}
 
-	//Update and check subroute 1 to private.
+	// Update and check subroute 1 to private.
 	serviceName1 := serviceNameForRoute(subrouteTag1, resources.Route.Name)
-	svc1, err := clients.KubeClient.Kube.CoreV1().Services(test.ServingNamespace).Get(serviceName1, metav1.GetOptions{})
+	svc1, err := clients.KubeClient.CoreV1().Services(test.ServingFlags.TestNamespace).Get(context.Background(), serviceName1, metav1.GetOptions{})
 	if err != nil {
-		t.Fatalf("Failed to get k8s service to modify: %v", err)
+		t.Fatal("Failed to get k8s service to modify:", err)
 	}
 
 	svc1Copy := svc1.DeepCopy()
@@ -349,12 +340,12 @@ func TestSubrouteVisibilityPrivateToPublic(t *testing.T) {
 		t.Fatalf(err.Error())
 	}
 
-	if _, err = clients.KubeClient.Kube.CoreV1().Services(test.ServingNamespace).Patch(serviceName1, types.JSONPatchType, svc1patchBytes); err != nil {
-		t.Fatalf("Failed to patch service: %v", err)
+	if _, err = clients.KubeClient.CoreV1().Services(test.ServingFlags.TestNamespace).Patch(context.Background(), serviceName1, types.JSONPatchType, svc1patchBytes, metav1.PatchOptions{}); err != nil {
+		t.Fatal("Failed to patch service:", err)
 	}
 
 	if err = v1test.WaitForRouteState(clients.ServingClient, resources.Route.Name, v1test.IsRouteReady, "Route is ready"); err != nil {
-		t.Fatalf("Route did not become ready: %v", err)
+		t.Fatal("Route did not become ready:", err)
 	}
 
 	if isClusterLocal, err := isTrafficClusterLocal(publicRoute.Status.Traffic, subrouteTag1); err != nil {
@@ -368,14 +359,14 @@ func TestSubrouteVisibilityPrivateToPublic(t *testing.T) {
 func isTrafficClusterLocal(tt []v1.TrafficTarget, tag string) (bool, error) {
 	for _, traffic := range tt {
 		if traffic.Tag == tag {
-			return strings.HasSuffix(traffic.URL.Host, network.GetClusterDomainName()), nil
+			return strings.HasSuffix(traffic.URL.Host, ".local"), nil
 		}
 	}
-	return false, fmt.Errorf("Unable to find traffic target with tag %s", tag)
+	return false, fmt.Errorf("unable to find traffic target with tag %s", tag)
 }
 
 func isRouteClusterLocal(rs v1.RouteStatus) bool {
-	return strings.HasSuffix(rs.URL.Host, network.GetClusterDomainName())
+	return strings.HasSuffix(rs.URL.Host, ".local")
 }
 
 func serviceNameForRoute(subrouteTag, routeName string) string {
